@@ -113,13 +113,12 @@ A comparison of sc, bcc and fcc nanoparticles (takes a while )
 
 END
 """
-from __future__ import division
-from __future__ import print_function
 
 import re
 import numbers
 import numpy as np
 from numpy import linalg as la
+from scipy.spatial.transform import Rotation
 
 from . import parallel
 from .dataarray import dataArray as dA
@@ -463,9 +462,10 @@ class lattice(object):
             center = [0, 0, 0]
         v = np.array(vector)
         c = np.array(center)
-        vv = (v ** 2).sum() ** 0.5
-        v = v / vv
-        choose = np.dot(self._points[:, :3] - c, v) > 0
+        v = v / la.norm(v)
+        # np.dot is not thread safe
+        dd = np.einsum('ij,j', self._points[:, :3] - c, v)
+        choose = (dd > 0)
         if invert:
             self._points[~choose, 3] = b
         else:
@@ -517,6 +517,58 @@ class lattice(object):
         else:
             self._points[choose, 3] = b
 
+    def inEllipsoid(self, abc, rotation=None, center=None, b=1, invert=False):
+        """
+        Set scattering length for points in ellipsoid.
+
+        Parameters
+        ----------
+        abc: [float,float,float]
+            Principal semi axes length of the ellipsoid.
+        rotation : scipy.spatial.transform.Rotation object
+            Rotation describing the rotation semi axes rotation from the cartesian axes.
+            e.g. `scipy.spatial.transform.Rotation.from_rotvec([np.pi/4, 0, 0])`
+        center : 3 x float, default [0,0,0]
+            Center of the sphere.
+        b:  float
+            Scattering length for selected points.
+        invert : bool
+            True to invert selection.
+
+        Examples
+        --------
+        ::
+
+         import jscatter as js
+         from scipy.spatial.transform import Rotation as R
+         sc=js.sf.scLattice(0.5,30,b=[0])
+         sc.inEllipsoid(abc=[3,1,12],b=1)
+         sc.show()
+         sc.inEllipsoid(abc=[3,1,12],rotation=R.from_euler('X',45,degrees=True),b=2)
+         sc.show()
+         sc.inEllipsoid(abc=[3,1,12],rotation=R.from_euler('XY',[45,90],degrees=True),b=3)
+         sc.show()
+
+
+
+        """
+        abc=np.array(abc)
+        if center is None:
+            center = [0, 0, 0]
+
+        # subtract center
+        points = self._points[:, :3] - np.array(center)
+        if rotation is not None:
+            # this should be a scipy.spatial.transform.rotation object
+            points=rotation.apply(points)
+        # scale to normal form of ellipsoid and use norm<1
+        scaledellipscoord = (points) / abc
+        choose = la.norm(scaledellipscoord, axis=1) < 1
+        if invert:
+            self._points[~choose, 3] = b
+        else:
+            self._points[choose, 3] = b
+
     def alongLine(self, v, R, a=None, direction=0, b=1, invert=False):
         """
         Set scattering length for points within a long cylinder.
@@ -557,7 +609,8 @@ class lattice(object):
         a = np.array(a)
         n = v / la.norm(v)
         p = a - self._points[:, :3]
-        pn = np.dot(p, n)
+        # np.dot is not thread safe
+        pn = np.einsum('ij,j', p, n)
         choose = la.norm(p - (pn * n[:, None]).T, axis=1) < abs(R)
         if direction > 0:
             choose[pn > 0] = False
@@ -569,24 +622,7 @@ class lattice(object):
         else:
             self._points[choose, 3] = b
 
-    def _inEllipsoid(self, center, v, Rmajor, Rminor, b=1, invert=False):
-        # only for prolate ellipsoid
-        v = np.array(v)
-        center = np.array(center)
-        v = v /la.norm(v)
-        c = abs(Rmajor ** 2 - Rminor ** 2) ** 0.5
-        # 2 Foci
-        P1 = center - v * c
-        P2 = center + v * c
-        a2 = abs(Rmajor * 2)
-        print(P1, P2, c, a2)
-        choose = (la.norm(self._points[:, :3] - P1, axis=1) + la.norm(self._points[:, :3] - P2, axis=1)) < a2
-        if invert:
-            self._points[~choose, 3] = b
-        else:
-            self._points[choose, 3] = b
-
-    def show(self, R=None, cmap='rainbow', fig=None, ax=None, atomsize=6):
+    def show(self, R=None, cmap='rainbow', fig=None, ax=None, atomsize=1):
         """
         Show the lattice in matplotlib with scattering length color coded.
 
@@ -621,7 +657,6 @@ class lattice(object):
             points = self.points
         else:
             points = self.points[la.norm(self.points[:, :3], axis=1) < R]
-        upoints = np.array(self.unitCellAtomPositions)
 
         if len(points) == 0:
             raise AttributeError('No points with b>0 to show')
@@ -647,35 +682,39 @@ class lattice(object):
             else:
                 # r,c,i = ax.get_geometry()
                 ax.clear()
-
+        # scatter plot of points
         ax.scatter(points[:, 0], points[:, 1], points[:, 2], c=points[:, 3], s=points[:, 3] / bmin * atomsize ** 2,
                    cmap=cmap, vmin=bmin, vmax=bmax, depthshade=False)
-        ax.scatter(upoints[:, 0], upoints[:, 1], upoints[:, 2], c=self.unitCellAtoms_b,
-                   s=self.unitCellAtoms_b / bmin * atomsize ** 2,
-                   cmap=cmap, vmin=bmin, vmax=bmax, depthshade=False)
-
-        # unit cell edge vectors
-        lv = self.latticeVectors
-        if len(lv) > 1:
-            line = [lv[0] * 0, lv[0], lv[0] + lv[1], lv[1], lv[0] * 0]
-        if len(lv) > 2:
-            line += [lv[2], lv[2] + lv[0], lv[0], lv[2] + lv[0],
-                     lv[2] + lv[0] + lv[1], lv[0] + lv[1], lv[2] + lv[0] + lv[1],
-                     lv[2] + lv[1], lv[1], lv[2] + lv[1],
-                     lv[2] + lv[0] * 0]
-        line = np.array(line)
-        ax.plot(line[:, 0], line[:, 1], line[:, 2], color='g')
-        # lines to unit cell atoms if less than 6
-        if len(self.unitCellAtoms) < 7:
-            try:
-                for uca in self.unitCellAtomPositions:
-                    if la.norm(uca) == 0:
-                        # atom in origin
-                        pass
-                    ax.plot([0, uca[0]], [0, uca[1]], [0, uca[2]], color='b')
-            except (AttributeError, IndexError):
-                pass
 
+        # try to plot unit cell with edge vectors
+        try:
+            upoints = np.array(self.unitCellAtomPositions)
+            ax.scatter(upoints[:, 0], upoints[:, 1], upoints[:, 2], c=self.unitCellAtoms_b,
+                       s=self.unitCellAtoms_b / bmin * atomsize ** 2,
+                       cmap=cmap, vmin=bmin, vmax=bmax, depthshade=False)
+            # unit cell edge vectors
+            lv = self.latticeVectors
+            if len(lv) > 1:
+                line = [lv[0] * 0, lv[0], lv[0] + lv[1], lv[1], lv[0] * 0]
+            if len(lv) > 2:
+                line += [lv[2], lv[2] + lv[0], lv[0], lv[2] + lv[0],
+                         lv[2] + lv[0] + lv[1], lv[0] + lv[1], lv[2] + lv[0] + lv[1],
+                         lv[2] + lv[1], lv[1], lv[2] + lv[1],
+                         lv[2] + lv[0] * 0]
+            line = np.array(line)
+            ax.plot(line[:, 0], line[:, 1], line[:, 2], color='g')
+            # lines to unit cell atoms if less than 6
+            if len(self.unitCellAtoms) < 7:
+                try:
+                    for uca in self.unitCellAtomPositions:
+                        if la.norm(uca) == 0:
+                            # atom in origin
+                            pass
+                        ax.plot([0, uca[0]], [0, uca[1]], [0, uca[2]], color='b')
+                except (AttributeError, IndexError):
+                    pass
+        except AttributeError:
+            pass
         ax.set_xlabel('x axis')
         ax.set_ylabel('y axis')
         ax.set_zlabel('z axis')
@@ -1019,7 +1058,7 @@ class rhombicLattice(lattice):
 
         return np.c_[bbb[choose], f2hkl[choose], hkl[choose]]
 
-    def getRadialReciprocalLattice(self, size, includeZero=False):
+    def getRadialReciprocalLattice(self, size):
         """
         Get radial distribution of Bragg peaks with unit cell structure factor and multiplicity.
 
@@ -1030,8 +1069,6 @@ class rhombicLattice(lattice):
         ----------
         size : int
             Size of the lattice as maximum included Miller indices.
-        includeZero : bool
-            Include q=0 peak
 
         Returns
         -------
@@ -1046,7 +1083,7 @@ class rhombicLattice(lattice):
         qrunique, qrindex, qrcount = np.unique(np.floor(qr * tol) / tol, return_index=True, return_inverse=False,
                                                return_counts=True)
         # q values of unique peaks, scattering strength f2hkl, multiplicity as number of unique peaks from 3D count
-        if includeZero:
+        if qrunique[0] > 0:
             return qrunique, f2hkl[qrindex], qrcount, hkl[qrindex]
         else:
             return qrunique[1:], f2hkl[qrindex][1:], qrcount[1:], hkl[qrindex][1:]
@@ -1778,7 +1815,7 @@ class latticeFromCIF(rhombicLattice):
 
            # Simply install by
            pip install pymatgen
-
+        - Pymatgen allows site occupancy which is taken here into account as average scattering length per site.
         - Pymatgen allows reading of CIF files or to get directly a structure from
           `Materials Project <https://materialsproject.org/>`_
           or `Crystallography Open Database <http://www.crystallography.net/cod/>`_ .
@@ -1832,14 +1869,19 @@ class latticeFromCIF(rhombicLattice):
         else:
             # assume it is a pymatgen structure
             cif = structure
-        elements = [ele.name for ele in cif.species]
 
         if typ[0] == 'n':
-            # coherent neutron scattering length
-            b = [formel.Nscatlength[ele.lower()][0] for ele in elements]
+            # coherent neutron scattering length using fractional occupancies
+            b=[]
+            for specOcc in cif.species_and_occu:
+                names = [e.name for e in specOcc.elements]
+                b_frac = [formel.Nscatlength[n.lower()][0]*specOcc.element_composition.get_atomic_fraction(n)
+                          for n in names]
+                b.append(np.sum(b_frac))
         else:
-            # xray scattering length
-            b = [formel.Elements[ele.lower()][0] * formel.felectron for ele in elements]
+            # xray scattering length using number of electrons
+            # species_and_occu averages occupancy of different atoms on sites
+            b = [specOcc.total_electrons * formel.felectron for specOcc in cif.species_and_occu]
 
         rhombicLattice.__init__(self, latticeVectors=cif.lattice.matrix * 0.1, size=size,
                                 unitCellAtoms=cif.frac_coords, b=b)
