@@ -18,7 +18,7 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
-This is a rudimentary interface to matplotlib to use dataArrays/sasImage easier.
+This is a rudimentary interface to `matplotlib <https://matplotlib.org/>`_ to use dataArrays/sasImage easier.
 The standard way to use matplotlib is full available without using this module.
 Nevertheless the source can be used as template to be adapted.
 
@@ -453,7 +453,7 @@ class jspaperAxes(matplotlib.axes.Axes):
         self.set_ylim(min, max)
         if scale is not None:
             if scale[0] == 'l':
-                self.set_yscale(value='log', nonposy='clip', subsy=[2, 3, 4, 5, 6, 7, 8, 9])
+                self.set_yscale(value='log', nonpositive='clip', subs=[2, 3, 4, 5, 6, 7, 8, 9])
             else:
                 self.set_yscale(value='linear')
 
@@ -487,7 +487,7 @@ class jspaperAxes(matplotlib.axes.Axes):
         self.set_xlim(min, max)
         if scale is not None:
             if scale[0] == 'l':
-                self.set_xscale(value='log', nonposx='clip', subsx=[2, 3, 4, 5, 6, 7, 8, 9])
+                self.set_xscale(value='log', nonpositive='clip', subs=[2, 3, 4, 5, 6, 7, 8, 9])
             else:
                 self.set_xscale(value='linear')
         self.figure.show()
@@ -509,8 +509,8 @@ class jspaperAxes(matplotlib.axes.Axes):
             Location specifier
             - ‘best’ 	0, ‘upper right’ 1, ‘upper left’ 2, ‘lower left’ 3, ‘lower right’ 4,‘center left’ 6,
         x,y : float [0..1]
-            Determines **if both** given loc and sets position in axes coordinates.
-            Sets bbox_to_anchor=(x,y)
+            Determines, **if both** given, loc and sets position in axes coordinates.
+            Sets bbox_to_anchor=(x,y). Values outside [0,1] are ignored.
         kwargs : kwargs of axes.legend
             Any given kwarg overrides the previous
 
@@ -522,7 +522,9 @@ class jspaperAxes(matplotlib.axes.Axes):
         if 'labelspacing' not in kwargs: kwargs['labelspacing'] = 0.2
         if 'loc' not in kwargs: kwargs['loc'] = 0  # best
         x = kwargs.pop('x', None)
+        if x is not None and ((x>1) or (x<0)): x = None
         y = kwargs.pop('y', None)
+        if y is not None and ((y > 1) or (y < 0)): x = None
         _ = kwargs.pop('position', None)
         if x is not None and y is not None:
             kwargs['loc'] = 'upper right'
@@ -1564,6 +1566,148 @@ def showlastErrPlot2D(data, lastfit=None, shape=None, scale='norm', colorMap='je
     return fig
 
 
+def plot2Dimage(data, shape=None, yaxis_label='Z', xaxis_label='X', method='nearest', colorMap='jet', scale='norm',
+                linthresh=1, linscale=1, badcolor=None, transpose=None, figsize=[6, 6], origin='upper',
+                txtkwargs={'fontsize': 'small'}):
+    """
+    Show a 2D image of a dataarray with XZW values like from oriented cloudscattering.
+
+    Parameters
+    ----------
+    data : dataArray
+        dataArray optional with fit values in lastfit.
+    shape : [int,int]
+        Optional shape of the data if these are from an image.
+        If not given the data are interpolated (regrid)
+    yaxis_label : string
+    xaxis_label : string
+    method : float,'linear', 'nearest', 'cubic'
+        Filling value for new points as float or order of interpolation
+        between existing points.
+        See `griddata <https://docs.scipy.org/doc/scipy/reference/generated/scipy.interpolate.griddata.html>`_
+    colorMap : string
+        Get a colormap instance from name.
+        Standard mpl colormap name (see showColors).
+    scale : 'log', 'symlog', default = 'norm'
+        Scale for intensities.
+
+        - 'norm' Linear scale.
+        - 'log' Logarithmic scale
+        - 'symlog' Symmetrical logarithmic scale is logarithmic in both the positive
+          and negative directions from the origin. This works also for only positive data.
+          Use linthresh, linscale to adjust.
+    linthresh : float, default = 1
+        Only used for scale 'sym'.
+        The range within which the plot is linear (-linthresh to linthresh).
+    linscale : float, default = 1
+        Only used for scale 'sym'.
+        Its value is the number of decades to use for each half of the linear range.
+        E.g. 10 uses 1 decade.
+    badcolor : float, color
+        Set the color for bad values (like masked pixel) values in an image.
+        Default is  bad values be transparent.
+        Color can be matplotlib color as 'k','b' or
+        float value in interval [0,1] of the chosen colorMap.
+        0 sets to minimum value, 1 to maximum value.
+    transpose : bool
+        Transpose coordinates, e.g. for sasImages.
+    figsize : [float,float], default [6,6]
+        Figure Size in inch.
+    txtkwargs : kwargs
+        Keyword arguments passed to Text https://matplotlib.org/api/text_api.html#matplotlib.text.Text).
+        except x,y,text arguments.
+
+
+    Returns
+    -------
+        figure
+
+    Examples
+    --------
+    ::
+
+     import jscatter as js
+     import numpy as np
+
+     R=8    # maximum
+     N=200  # number of points
+     ds=15;
+     qxy=np.mgrid[-R:R:N*1j, -R:R:N*1j].reshape(2,-1).T
+     # add z=0 component
+     qxyz=np.c_[qxy,np.zeros(qxy.shape[0])].T # as position vectors
+     # create fcc lattice which includes reciprocal lattice vectors and methods to get peak positions
+     fcclattice= js.lattice.fccLattice(5, 5)
+     # Orient 111 direction perpendicular to qxy plane
+     fcclattice.rotatehkl2Vector([1,1,1],[0,0,1])
+     # rotation by 15 degrees to be aligned to xy plane
+     fcclattice.rotateAroundhkl([1,1,1],np.deg2rad(15))
+     ffs=js.sf.orientedLatticeStructureFactor(qxyz,fcclattice, rotation=[1,1,1,np.deg2rad(10)],
+                                domainsize=ds,rmsd=0.1,hklmax=5,nGauss=23)
+
+     js.mpl.plot2Dimage(ffs)
+
+    .. image:: ../../examples/images/2dfccplot.png
+     :align: center
+     :width: 70 %
+     :alt: 2dfccplot
+
+
+   """
+    # use copy so that we do not mutate the global colormap instance; stupid matplotlib programmers
+    cmap = copy.copy(matplotlib.cm.get_cmap(colorMap))
+    # if hasattr(data, 'W') and shape is None:
+    #  print('This function does not yet handle 3D data!')
+    #   return
+    if badcolor is not None:
+        # set bad color
+        if isinstance(badcolor, numbers.Number):
+            cmap.set_bad(color=cmap(badcolor))
+        else:
+            cmap.set_bad(color=badcolor)
+
+    # determine the scaling (norm)
+    # determine vmin,vmax later
+    if scale[:3] == 'log':
+        norm1 = colors.LogNorm(clip=True)
+    elif scale[:3] == 'sym':
+        norm1 = colors.SymLogNorm(clip=True, linthresh=linthresh, linscale=linscale)
+    else:  # default: scale == 'normalize':
+        norm1 = colors.Normalize(clip=True)
+    norm2 = colors.Normalize(clip=True)
+
+    if shape is not None:
+        X, Z, Y = regrid(data.X, data.Z, data.Y, shape)
+
+        extend = [np.min(Z), np.max(Z), np.min(X), np.max(X)]
+
+
+    else:
+
+        X, Z, Y = regrid(data.X, data.Z, data.Y)
+        extend = [np.min(Z), np.max(Z), np.min(X), np.max(X)]
+
+    if transpose:
+        Y = Y.T
+
+        extend = [extend[2], extend[3], extend[0], extend[1]]
+
+    fig = figure(figsize=figsize)
+    ax1 = fig.add_subplot(1, 1, 1)
+
+    # add images and and some text
+    norm1.autoscale(Y)
+    im1 = ax1.imshow(Y, cmap=cmap, norm=norm1, extent=extend, origin=origin)
+
+    fig.colorbar(im1, ax=ax1, pad=0.01, shrink=0.85)
+
+    ax1.set_ylabel(yaxis_label)
+    ax1.set_xlabel(xaxis_label)
+
+    # get lastfit attributes
+    show(block=False)
+    return fig
+
+
 def test(keepopen=True):
     """
     A small test for mpl module making a plot.
@@ -1664,3 +1808,5 @@ def test(keepopen=True):
         return fig4
     else:
         js.mpl.pyplot.close('all')
+
+
