@@ -40,8 +40,6 @@ provides the **sasImage** class to read and analyse 2D detector images from SAXS
 
 
 """
-from __future__ import print_function
-from __future__ import division
 
 import copy
 import fnmatch
@@ -331,15 +329,16 @@ def _smear(q, data):
 
 def smear(unsmeared=None, *, beamProfile=None, **smkwargs):
     r"""
-    Smearing model/data for point collimation SANS/SAXS or line-collimated SAXS (Kratky camera).
+    Smearing model/data for point collimation SANS/SAXS or line-collimated SAXS (Kratky camera)
+    allowing simultaneous SAXS/SANS fitting.
 
     The beamProfile parameter has to be given as keyword argument ``beamProfile=mybeam``.
 
     Smearing at detector edges involves evaluation of the model at extrapolated q values.
      * For model functions smear is used as decorator ``@smear`` and the q range is automatically extended.
-     * If a model has beamProfile as parameter and gets a valid beamProfile during function call
-       this is used. This allows fitting with different profiles if the corresponding data contain .beamProfile
-       as attribute. See Notes.
+     * Simultaneous fitting of SAXS/SANS (inclusive multiple detector distances) the
+       data need corresponding ``.beamProfile`` as attribute.
+       During fitting ``.beamprofile`` is used for smearing of the model. See Notes for usage.
      * For explicit given data extrapolation at each edge needs to be chosen according
        to the observed behaviour at the edge (eg power law at low q or constant at high q).
        See prepareBeamProfile for the options.
@@ -378,8 +377,8 @@ def smear(unsmeared=None, *, beamProfile=None, **smkwargs):
     **The model scattering vector must have a name starting with one of "qQ".**
 
     * Beamprofile parameters as *detDist* are updated for smearing during the function call.
-      This allows that during fitting of datasets with different *detDist* always the correct smearing is used.
-      Setting any of the beamprofile parameters to *None* bypasses smearing.
+      This allows that during fitting with different *detDist* always the correct smearing is used.
+      Setting any of the beamprofile parameters to *None* bypasses smearing (e.g. for SAXS or simulation).
 
       Use as : ::
 
@@ -397,7 +396,8 @@ def smear(unsmeared=None, *, beamProfile=None, **smkwargs):
        # also for fitting with attribute detDist and collDist in fitted data for different detector distances
        sp=sphere(q=q,R=13,detDist=8000,collDist=8000.)
 
-      The above decorator is equivalent to the following. Use `smearedsphere` as smeared model function.
+      The above decorator is equivalent to the following.
+      Use `smearedsphere` as smeared model function.
       ::
 
        def sphere(q,R,bgr,detDist=3000,collDist=2000.,contrast=1):
@@ -406,7 +406,7 @@ def smear(unsmeared=None, *, beamProfile=None, **smkwargs):
            return sp
        smearedsphere=js.sas.smear(sphere,beamProfile=resol2m)
 
-    * To **fit SAXS and SANS data together** (also with different collimation)
+    * To **fit SAXS and SANS data together** (also with changing collimation)
       use the parameter beamProfile in the model.
       If calling the smeared model with a valid beamProfile this is used instead of the one defined in @smear
       One may remind that also pinhole SAXS has a smearing even if it is small.
@@ -434,7 +434,7 @@ def smear(unsmeared=None, *, beamProfile=None, **smkwargs):
        dll[1].beamProfile=fbeam2
        dll.fit(sphere,.....)
 
-    * Using **merged data** (multiple detector distances in one set with overlap) is possible
+    * Using **merged data** (multiple detector distances in one set of data with overlap) is possible
       with 'explicit' beamProfile  if (in particular in the overlap region):
        - no *q* value is used twice
        - for each value a resolution width exists
@@ -448,7 +448,7 @@ def smear(unsmeared=None, *, beamProfile=None, **smkwargs):
     The default is a constant value from the edge which is good for a low q plateau or a high q flat background.
     For the above model smearing this is not important as the q range is automatically extended.
     For desmearing e.g. of multi detector distance SANS data this is important
-    if detector edges are within a nonconstant region.
+    if detector edges are within a non constant region.
     ::
 
      import jscatter as js
@@ -515,27 +515,55 @@ def smear(unsmeared=None, *, beamProfile=None, **smkwargs):
          return sp
      #
      # prepare different beamprofiles
-     beam=js.sas.readpdh(js.examples.datapath+'/BeamProfile.pdh')
+     # measured Kratky camera BeamProfile.pdh for line collimation
+     beam = js.sas.readpdh(js.examples.datapath+'/BeamProfile.pdh')
      mbeam = js.sas.prepareBeamProfile(beam , bxw=0.01, dIW=1.)
+     #
+     # Kratky camera with explicit given beamprofile parameters describing trapezoidal beam profile
      tbeam = js.sas.prepareBeamProfile('trapez', a=mbeam.a, b=mbeam.b, bxw=0.01, dIW=1)
-     Sbeam1 = js.sas.prepareBeamProfile('SANS', detDist=1000,wavelength=0.4,wavespread=0.1)
-     Sbeam2 = js.sas.prepareBeamProfile('SANS', detDist=10000,wavelength=0.4,wavespread=0.1)
-     i7=js.dL(js.examples.datapath+'/polymer.dat')
-     Gbeam = js.sas.prepareBeamProfile(i7[0],explicit=3)
+     #
+     # different SANS detector distances, see  prepareBeamProfile for default parameters
+     Sbeam1 = js.sas.prepareBeamProfile('SANS', detDist=2000,wavelength=0.4,wavespread=0.1,sampleAperture=5)
+     Sbeam2 = js.sas.prepareBeamProfile('SANS', detDist=20000,wavelength=0.4,wavespread=0.1,sampleAperture=5)
+     #
+     # Using an explicit given resolution width in column 3
+     i70=js.dL(js.examples.datapath+'/polymer.dat')[0]
+     i70[3]*=10
+     Gbeam = js.sas.prepareBeamProfile(i70,explicit=3)
+     #
+     # Using a single width e.g. for point collimation SAXS data
+     # the width corresponds to Gaussian width from attenuated empty beam measurement
+     fbeam = js.sas.prepareBeamProfile(0.01)
+
 
      # smear data
-     data=sphere(q,R=13,bgr=1000)
-     datasm= js.sas.smear(unsmeared=data,beamProfile=mbeam)
-     datast= js.sas.smear(unsmeared=data,beamProfile=tbeam)
-     datasS1= js.sas.smear(unsmeared=data,beamProfile=Sbeam1)
-     datasS2= js.sas.smear(unsmeared=data,beamProfile=Sbeam2)
-     datasG= js.sas.smear(unsmeared=data,beamProfile=Gbeam)
+     data = sphere(q,R=25,bgr=1000)
+     datasm = js.sas.smear(unsmeared=data,beamProfile=mbeam)
+     datast = js.sas.smear(unsmeared=data,beamProfile=tbeam)
+     datasS1 = js.sas.smear(unsmeared=data,beamProfile=Sbeam1)
+     datasS2 = js.sas.smear(unsmeared=data,beamProfile=Sbeam2)
+     datasG = js.sas.smear(unsmeared=data,beamProfile=Gbeam)
+     datasf = js.sas.smear(unsmeared=data,beamProfile=fbeam)
 
      p=js.grace()
-     for dat in [data,datasm,datast,datasS1,datasS2,datasG]:
-        p.plot(dat)
+     p.title('resolution smearing in small angle scattering')
+     p.plot(data,li=[1,2,-1],sy=0,le='unsmeared')
+     for dat in [datasm,datast,datasS1,datasS2,datasG,datasf]:
+        p.plot(dat,li=[1,2,-1],sy=0,le=dat.beamProfile.beamProfType)
      p.yaxis(scale='l')
      p.xaxis(scale='l')
+     p.legend(x=1,y=1e8)
+     p.text(r'Kratky camera \nline collimation' , x=0.02,y=2e7)
+     p.text('point collimation' , x=0.2,y=8e8)
+     p.xaxis(label=r'Q / nm\S-1')
+     p.yaxis(label=r'I(Q) / a.u.')
+     #p.save(js.examples.imagepath+'/smearingexamples.png')
+
+    .. image:: ../../examples/images/smearingexamples.png
+     :width: 70 %
+     :align: center
+     :alt: smearingexamples
+
 
     """
 
@@ -660,7 +688,7 @@ def smear(unsmeared=None, *, beamProfile=None, **smkwargs):
 
 
 def desmear(Ios, beamProfile, NIterations=-15, windowsize=4, qmax=4, output=True, **kwargs):
-    """
+    r"""
     Desmearing of measured data according to Lake algorithm with possibility to stop recursion at best desmearing.
     
     For negative NIterations the iterations are stopped if a convergence criterion reaches
@@ -674,9 +702,9 @@ def desmear(Ios, beamProfile, NIterations=-15, windowsize=4, qmax=4, output=True
         Original smeared data
     beamProfile : dataArray
         Beam profile as prepared with prepareBeamProfile
-    NIterations : int, default=-15
+    NIterations : int, default=-15 (<0 automatic mode)
         Number of iterations to stop.
-        Negative values indicate to stop when convergence criterion increases again (as described by Vad [2]_)
+        *automatic mode*:  NIterations<0: stops when convergence criterion increases again (as described by Vad [2]_)
         and abs(NIterations) is maximum number of iterations.
     qmax : float, default=4
         Maximum in scattering vector q up to where the convergence criterion is evaluated.
@@ -689,7 +717,30 @@ def desmear(Ios, beamProfile, NIterations=-15, windowsize=4, qmax=4, output=True
     Returns
     -------
         dataArray
-    
+
+    Notes
+    -----
+    The Lake algorithm approximates the unsmeared scattering cross section iteratively
+    (n>0, with :math:`u_0(q)=I_{observed}(q)`) as
+
+    .. math:: u_n(q) = \frac{I_{observed}(q)u_{n-1}(q)}{\int_{q`}u_{n-1}(q`)R(q,q`)dq`}
+
+    The iterative method converges if [2]_
+
+    .. math:: \gamma_n(q) = \frac{I_{observed}(q)}{\int_{q`}u_{n-1}(q`)R(q,q`)dq`} \to 1
+
+    The convergence criterion is
+
+    .. math:: |<\gamma_n(q)>-1| = minimum
+
+    which means that the iterative algorithm is stopped if :math:`<\gamma_n(q)>` increases again because
+    amplified noise leads to increasing :math:`<\gamma_n(q)>`.
+
+    Here :math:`<>` is the average over all :math:`q` and
+    :math:`R(...)` is the resolution function smearing the measurement.
+
+
+
     References
     ----------
     .. [1] Lake, J. A. (1967). Acta Cryst. 23, 191–194.
@@ -845,7 +896,7 @@ def prepareBeamProfile(data=None, **kwargs):
         beam = dA(np.c_[[0.1, 1], [data, data]].T)
         beam.beamProfType = 'explicit'
     else:
-        # an empty array data ist string 'SANS' or 'trapz'
+        # an empty array, data ist string 'SANS' or 'trapz'
         beam = zeros((2, 6))
         beam.beamProfType = data
     for attr in ['collDist', 'collAperture', 'detDist', 'sampleAperture', 'wavespread', 'dpixelWidth',
@@ -1444,7 +1495,7 @@ def waterXrayScattering(composition='h2o1', T=293, units='mol'):
     r"""
     Absolute scattering of water with components (salt, buffer) at Q=0 as reference for X-ray.
 
-    According to [2]_ a buffer of water with components might be used.
+    According to [1]_ a buffer of water with components might be used.
     Ions need to be given separatly as ['55.51h2o1','0.15Na1','0.15Cl1'] for 0.15 M NaCl solution.
     It is accounted for the temperature dependence of water density and compressibility.
 
@@ -1453,7 +1504,7 @@ def waterXrayScattering(composition='h2o1', T=293, units='mol'):
     composition : string
         Buffer composition as in scatteringLengthDensityCalc
         give dissociated ions separatly as ['1Na','1Cl'] with concentration in mol prepended
-        the additional scattering as ionic liquid of the ions in water is taken into account see [2]_
+        the additional scattering as ionic liquid of the ions in water is taken into account see [1]_ .
         mass in g; 1000g water are 55.508 mol
     T : float
         Temperature in °K
@@ -1464,14 +1515,15 @@ def waterXrayScattering(composition='h2o1', T=293, units='mol'):
 
     Returns
     -------
-        float absolute scattering length in Units 1/cm
+        float: absolute scattering length in Units 1/cm.
 
     References
     ----------
-    .. [1] SAXS experiments on absolute scale with Kratky systems using water as a secondary standard
-           Doris Orthaber et al. J. Appl. Cryst. (2000). 33, 218±225
-    .. [2] A high sensitivity pinhole camera for soft condensed matter
+    .. [1] A high sensitivity pinhole camera for soft condensed matter
            T. Zemb, O. Tache, F. Né, and O. Spalla, J. Appl. Crystallogr. 36, 800 (2003).
+    .. [2] SAXS experiments on absolute scale with Kratky systems using water as a secondary standard
+           Doris Orthaber et al. J. Appl. Cryst. (2000). 33, 218±225
+
 
     Notes
     -----
@@ -1488,11 +1540,26 @@ def waterXrayScattering(composition='h2o1', T=293, units='mol'):
      - :math:`n_{ei}`     number of electrons per molecule component i in Mol
      - :math:`\sum_{ci}`   is done for all ions separately if given
 
+    For references regarding :py:func:`~.formel.waterdensity` and
+    :py:func:`~.formel.watercompressibility` see respective functions in formel.
+
+    Examples
+    --------
+    ::
+
+     # pure H2O
+     js.sas.waterXrayScattering(['55.5h2o1'])  # 0.0164 1/cm
+     # phosphate buffer
+     js.sas.waterXrayScattering(['55.5h2o1','0.2na2h1P1O4','0.2na1H1p1o4','0.1h1'])  # 0.0965 1/cm
+     # 1M NaCl buffer
+     js.sas.waterXrayScattering(['55.5h2o1','1na1','1cl1'])  # 0.0360 1/cm
+     # 100mM NaCl buffer
+     js.sas.waterXrayScattering(['55.5h2o1','0.1na1','0.1cl1'])  # 0.0183 1/cm
+
     """
     # Units is MMTK
     # k_MMTK=0.00831447086363271 # in  kJ/mol/K
     k = 1.3806488e-23  # J/K
-    mw = 18.01528
     I0 = 0
     ch2o = 0
     cd2o = 0
@@ -1507,9 +1574,10 @@ def waterXrayScattering(composition='h2o1', T=293, units='mol'):
         if not re.match(r'\d', decomp[0]):  # add a 1 as concentration in front if not there
             decomp = [1] + decomp
         mass = np.sum([Elements[ele][1] * float(num) for ele, num in zip(decomp[1:][::2], decomp[1:][1::2])])
+        # number of electrons for component i
         nei = np.sum([Elements[ele][0] * float(num) for ele, num in zip(decomp[1:][::2], decomp[1:][1::2])])
         if units.lower() == 'mol':
-            ci = float(decomp[0])
+            ci = float(decomp[0])  # concentration in mol/l
         else:
             # if units!=mol we convert here from  mass to mol fraction
             ci = float(decomp[0]) / mass
@@ -1518,15 +1586,20 @@ def waterXrayScattering(composition='h2o1', T=293, units='mol'):
         elif ''.join(decomp[1:]) == 'd2o1':
             cd2o += ci
         else:
-            # units in m
-            I0 += ci * constants.N_A * 1000 * (felectron * 1e-9) ** 2 * nei ** 2  # in mol/m**3...
+            # sum ions up
+            # in mol/m**3...
+            I0 += ci * constants.N_A * 1000 * (felectron * 1e-9) ** 2 * nei ** 2
+        print(compo,mass,nei)
+
+    # water density and average molecular weight for h2o/d2o mixture
     dhfraction = cd2o / (ch2o + cd2o) if ch2o + cd2o != 0 else 0
-    I0 = I0 / (ch2o + cd2o) / (1000 / mw)
-    #  from g/ml to  m**-3
-    water_density = waterdensity(['%.4f' % (1 - dhfraction) + 'h2o1', '%.4f' % dhfraction + 'd2o1'],
-                                 T=T) * 1e6 / mw * constants.N_A
+    mw = 18.01528 + dhfraction * (20.0272-18.01528)
+    water_density = waterdensity(['%.4f' % (1 - dhfraction) + 'h2o1', '%.4f' % dhfraction + 'd2o1'], T=T)
+    water_density *= 1e6 / mw * constants.N_A  # from g/ml to  m**-3
     chi = watercompressibility(d2ofract=dhfraction, T=T, units='bar') * 1e-5  # in 1/Pa
+
     I0 += water_density ** 2 * (felectron * 1e-9 * 10) ** 2 * k * T * chi
+
     return I0 / 100.  # in 1/cm
 
 
@@ -1543,12 +1616,11 @@ def _find_peak(beam, edge):
 
 def transmissionCorrection(data, dark, emptybeam=None, edge=0.03, exposure=None):
     r"""
-    Subtract dark current, find primary beam, get transmission and normalize by transmission and exposure time.
+    Subtract dark current, find primary beam, get transmission count and normalize by transmission and exposure time.
     IN PLACE.
 
     For measurements including the primary beam from a semitransparent beamstop as from SAXSpace.
-    Transmission is the maximum of the primary beam peak after dark subtraction.
-    Allows easier comparison of measurements  with aged source (primary intensity change).
+    The maximum of the primary beam peak after dark subtraction determines transmission counts.
 
 
     Parameters
@@ -1557,8 +1629,12 @@ def transmissionCorrection(data, dark, emptybeam=None, edge=0.03, exposure=None)
         A measurement from a SAXSpace instrument read by js.dA('filename.pdh',lines2parameter=[2,3,4])
     dark : dataArray
         Dark current measurement.
-    emptybeam : dataArray,default=None
-        Empty beam measurement to subtract from measurement. dark will be subtracted of empty beam.
+    emptybeam : dataArray, float, default=None
+        Empty beam measurement to subtract from measurement.
+        - If it is a raw measurement (not transmission corrected) first *transmissionCorrection* is applied.
+          The transmission of emptybeam measurement is given in absolute units (counts/s)
+        - If float (as counts/s) this value is used as emptybeam primary beam intensity for calculation
+          of the actual sample transmission
     edge : float, default 0.03
         Wavevector value below beam stop edge. The primary beam is searched below this value.
     exposure : float, default None
@@ -1567,7 +1643,12 @@ def transmissionCorrection(data, dark, emptybeam=None, edge=0.03, exposure=None)
 
     Returns
     -------
-        None
+        None, IN PLACE
+         - Adds attributes *.centerTransmissionPeak*, *.centerTransmissionPeakMax* and *.transmission* as
+           relative transmission to primary beam for samples.
+         - If emptybeam is NOT given the transmission value is the maximum peak value in counts/s.
+           The same is for evaluating the emptybeam measurement itself.
+           To compare the treated emptybeam multiply with this maximum peak value.
 
     Notes
     -----
@@ -1602,7 +1683,7 @@ def transmissionCorrection(data, dark, emptybeam=None, edge=0.03, exposure=None)
      - :math:`I_b`      is the empty beam measurement
      - :math:`I_{EC}`   is the empty cell measurement
      - :math:`z_x`      corresponding sample thickness
-     - :math:`T_x`      corresponding transmission
+     - :math:`T_x`      corresponding transmission as primary beam intensity ratio :math:`T_x=I_x(0)/I_b(0)`
 
     The recurring pattern :math:`\big((\frac{I-I_{dark}}{T}-I_{b}T\big)` shows that the the beam tail
     (border of primary beam not absorbed by the beam stop) is attenuated by the corresponding sample.
@@ -1649,10 +1730,16 @@ def transmissionCorrection(data, dark, emptybeam=None, edge=0.03, exposure=None)
     if hasattr(data, 'transmission'):
         print('data has .transmission. It was already corrected and is not changed.')
         return
-    if emptybeam is None or hasattr(emptybeam, 'transmission'):
-        pass
+
+    if emptybeam is None:
+        EBtransmission = 1.
+    elif isinstance(emptybeam, numbers.Number):
+        EBtransmission = emptybeam
+    elif hasattr(emptybeam, 'transmission'):
+        EBtransmission = emptybeam.transmission
     else:
         transmissionCorrection(emptybeam, dark, emptybeam=None, edge=edge, exposure=None)
+        EBtransmission = emptybeam.transmission
 
     if data.X.min() > 0:
         raise Exception('data seem to have no transmission peak ')
@@ -1671,21 +1758,20 @@ def transmissionCorrection(data, dark, emptybeam=None, edge=0.03, exposure=None)
         pass
 
     # get transmission and peak
-    tp, bt = _find_peak(data, edge)
-    data.centerTransmissionPeak = tp
-    data.transmission = bt
+    centerTransmissionPeak, peakmax = _find_peak(data, edge)
+    data.centerTransmissionPeak = centerTransmissionPeak
+    data.centerTransmissionPeakMax = peakmax/data.Exposure[0]
+    data.transmission = peakmax/data.Exposure[0]/EBtransmission
 
     # normalize by exposure and transmission
     data.Y = data.Y / data.Exposure[0] / data.transmission
     data.eY = data.eY / data.Exposure[0] / data.transmission
+
     # scale and subtract emptybeam if given
     if emptybeam is not None:
-        try:
-            # subtract emptybeam
-            data.Y -= (data.transmission * emptybeam.Y)
-            data.eY = (data.eY ** 2 + (data.transmission * emptybeam.eY) ** 2) ** 0.5
-        except AttributeError:
-            pass
+        # subtract emptybeam
+        data.Y =  data.Y - (data.transmission * emptybeam.Y)
+        data.eY = (data.eY ** 2 + (data.transmission * emptybeam.eY) ** 2) ** 0.5
 
 
 def _w2f(word):
